Documentation
¶
Overview ¶
Package lookup3 implements Bob Jenkins' lookup3 hashlittle non-cryptographic hash function.
See:
https://en.wikipedia.org/wiki/Jenkins_hash_function
http://burtleburtle.net/bob/c/lookup3.c
While this package uses the Go standard library hash package interface hashlittle calls cannot be chained, i.e. all the bytes of the key need to be written to the hash object in a single call to Write(), as the hash is dependent on the key length. Making multiple calls to Write() would not yield the same result, and for this reason throws an error
This code is hereby placed in the public domain
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func HashLittle2 ¶
Hashlittle2 returns a new hash.Hash64 to calculate the 64-bit lookup3 hashlittle
Its Sum() method will lay the value out in big-endian byte order. and Sum64() will return the 64-bit unsigned value
Types ¶
This section is empty.